import gi
from gi.repository import Gtk
from services.noark_service import get_journalposter, create_journalpost, upload_document
from views.login_window import LoginWindow

class MainWindow(Gtk.ApplicationWindow):
    def __init__(self, app):
        super().__init__(application=app)
        self.set_title("Noark5 Journalposter")
        self.set_default_size(800, 600)

        self.box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL, spacing=6)
        self.set_child(self.box)

        self.header = Gtk.HeaderBar()
        self.set_titlebar(self.header)

        self.button_refresh = Gtk.Button(label="🔄")
        self.button_refresh.connect("clicked", self.load_data)
        self.header.pack_start(self.button_refresh)

        self.button_new = Gtk.Button(label="Ny journalpost")
        self.button_new.connect("clicked", self.new_journalpost)
        self.header.pack_end(self.button_new)

        self.button_upload = Gtk.Button(label="Last opp dokument")
        self.button_upload.connect("clicked", self.upload_to_selected)
        self.header.pack_end(self.button_upload)

        self.liststore = Gtk.ListStore(str, str, str)
        self.treeview = Gtk.TreeView(model=self.liststore)

        for i, title in enumerate(["ID", "Tittel", "Dato"]):
            renderer = Gtk.CellRendererText()
            column = Gtk.TreeViewColumn(title, renderer, text=i)
            self.treeview.append_column(column)

        scrolled = Gtk.ScrolledWindow()
        scrolled.set_child(self.treeview)
        self.box.append(scrolled)

        self.load_data()

    def load_data(self, *_):
        self.liststore.clear()
        for jp in get_journalposter():
            self.liststore.append([jp.get("systemID", ""), jp.get("tittel", ""), jp.get("opprettetDato", "")])

    def new_journalpost(self, *_):
        dialog = Gtk.MessageDialog(modal=True, text="Ny journalpost-tittel:")
        entry = Gtk.Entry()
        dialog.get_content_area().append(entry)
        dialog.add_button("Opprett", Gtk.ResponseType.OK)
        dialog.add_button("Avbryt", Gtk.ResponseType.CANCEL)
        response = dialog.run()
        if response == Gtk.ResponseType.OK:
            create_journalpost(entry.get_text())
            self.load_data()
        dialog.destroy()

    def upload_to_selected(self, *_):
        selection = self.treeview.get_selection()
        model, iter = selection.get_selected()
        if iter:
            journal_id = model[iter][0]
            dialog = Gtk.FileChooserDialog("Velg fil", self, Gtk.FileChooserAction.OPEN, ("Avbryt", Gtk.ResponseType.CANCEL, "Åpne", Gtk.ResponseType.OK))
            response = dialog.run()
            if response == Gtk.ResponseType.OK:
                upload_document(journal_id, dialog.get_file().get_path())
            dialog.destroy()
